@@ -1,4 +1,3 @@
-globalVariables("results")
 ETPlot <- function(results, type = "Aggregation", OBS, OBSplot = FALSE,  Sdate = time(results$ET.Daily)[1], Edate = time(results$ET.Daily)[length(results$ET.Daily)]) { # plot estimations and observations
   
   # Aggregation plot (default)
@@ -61,7 +60,7 @@ ETPlot <- function(results, type = "Aggregation", OBS, OBSplot = FALSE,  Sdate =
     par(ask=FALSE)
     plot.new()
     # Plots - Average
-    plot(results$ET.MonthlyAve~unique(1:12), main = paste("Monthly average", results$ET_formulation, results$ET_type), type = "o", ylim = c(0, max(results$ET.MonthlyAve)*1.5), xlab = "Month", ylab = list(c("Monthly average", results$ET_type, "mm/day")))
+    plot(results$ET.MonthlyAve~unique(1:12), main = paste("Monthly average", results$ET_formulation, results$ET_type), type = "o", ylim = c(0, max(results$ET.MonthlyAve)*1.5), xlab = "Month", ylab = list(c(paste("Monthly average", results$ET_type), "mm/day")))
     if (OBSplot == TRUE) {
       if (!is.null(OBS)) {
         lines(OBS$E_obs.MonthlyAve~unique(1:12), main = "Observed evaporation", type = "o", ylim = c(0,10), col = "RED", xlab = "Month", ylab = "Monthly average observed evaporation mm")
@@ -73,7 +72,7 @@ ETPlot <- function(results, type = "Aggregation", OBS, OBSplot = FALSE,  Sdate =
     
     par(ask=TRUE)
     
-    plot(results$ET.AnnualAve~unique(as.POSIXlt(data$Date.daily)$year + 1900), main = paste("Annual average", results$ET_formulation, results$ET_type), type = "o", ylim = c(0, max(results$ET.AnnualAve)*1.5), xlab = "Year", ylab = list(c("Annual average", results$ET_type, "mm/day")))
+    plot(results$ET.AnnualAve~unique(as.POSIXlt(data$Date.daily)$year + 1900), main = paste("Annual average", results$ET_formulation, results$ET_type), type = "o", ylim = c(0, max(results$ET.AnnualAve)*1.5), xlab = "Year", ylab = list(c(paste("Annual average", results$ET_type), "mm/day")))
     if (OBSplot == TRUE) {
       if (!is.null(OBS)) {
         lines(OBS$E_obs.AnnualAve~unique(as.POSIXlt(OBS$Date.OBS)$year + 1900), main = "Observed evaporation", type = "o", ylim = c(0,10), col = "RED", xlab = "Year", ylab = "Annual average observed evaporation mm")
@@ -92,7 +91,7 @@ ETPlot <- function(results, type = "Aggregation", OBS, OBSplot = FALSE,  Sdate =
 #-------------------------------------------------------------------------------------
 
 ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, results5 = NULL, results6 = NULL, results7 = NULL, 
-                         labs, Sdate, Edate, type = "Monthly", ylim) { # plot up to 7 estimations
+                         labs, Sdate=NULL, Edate=NULL, type = "Monthly", ylim=rep(NA,2)) { # plot up to 7 estimations
   # check number of sets of results to compare and compile list of legend text
   
   if (exists("results1")==F | exists("results2")==F) {
@@ -209,14 +208,14 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
       }
     }
     
-    if (is.null(ylim[1])) {
+    if (is.na(ylim[1])) {
       ylim[1] <- 0
     }
-    if (is.null(ylim[2])) {
+    if (is.na(ylim[2])) {
       ylim[2] <- max(results1$ET.Daily)*1.5
     }
     
-    plot(comp[,2]~as.Date(comp[,1]), type = "l", main = "Daily estimations of ET",  ylim = ylim, col = 2, xlab = "Year", ylab = "Estimated ET mm/day", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(comp[,2]~as.Date(comp[,1]), type = "l", main = "Daily estimations of ET",  ylim = ylim, col = 2, xlab = "Year", ylab = "Estimated ET mm/day", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (i in 1:(Ncomp-1)) {
       lines(comp[,i+2]~as.Date(comp[,1]), type = "o", pch = ".", col = i+2)
     }
@@ -233,7 +232,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     }
     sortcomp[,Ncomp+2] <- seq(from = 1/nrow(sortcomp), to = 1, by = 1/nrow(sortcomp))
     
-    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the daily ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Estimated daily ET mm/day", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the daily ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Estimated daily ET mm/day", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (k in 1:(Ncomp-1)) {
       lines(sortcomp[,k+2]~sortcomp[,Ncomp+2], type = "o", pch = ".", col = k+2)
     }
@@ -243,7 +242,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     # Box plot
     par(ask=TRUE)
     colnames(comp)[2:(Ncomp+1)] <- legtext
-    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the daily estimations of ET", xlab = "", ylab = "Distribution of daily PET in mm", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
+    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the daily estimations of ET", xlab = "", ylab = "Distribution of daily PET in mm", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
     legend("topright", inset = .01, c(paste(legtext[1:Ncomp])), cex = (1), fill = c(seq(from=2,to=Ncomp+1)), bty="o")
   }
   
@@ -324,7 +323,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
       ylim[2] <- max(results1$ET.Monthly)*1.5
     }
     
-    plot(comp[,2]~as.yearmon(comp[,1]), type = "l", main = "Monthly estimations of ET",  ylim = ylim, col = 2, xlab = "Year", ylab = "Monthly aggregations of estimated ET mm/month", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(comp[,2]~as.yearmon(comp[,1]), type = "l", main = "Monthly estimations of ET",  ylim = ylim, col = 2, xlab = "Year", ylab = "Monthly aggregations of estimated ET mm/month", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (i in 1:(Ncomp-1)) {
       lines(comp[,i+2]~as.yearmon(comp[,1]), type = "o", pch = ".", col = i+2)
     }
@@ -342,7 +341,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     }
     sortcomp[,Ncomp+2] <- seq(from = 1/nrow(sortcomp), to = 1, by = 1/nrow(sortcomp))
     
-    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the monthly ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Monthly aggregations of estimated ET mm/month", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the monthly ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Monthly aggregations of estimated ET mm/month", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (k in 1:(Ncomp-1)) {
       lines(sortcomp[,k+2]~sortcomp[,Ncomp+2], type = "o", pch = ".", col = k+2)
     }
@@ -352,7 +351,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     # Box plot
     par(ask=TRUE)
     colnames(comp)[2:(Ncomp+1)] <- legtext
-    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), main = "Box plot of the monthly estimations of ET", boxwex = 0.5, range = 0, xlab = "", ylab = "Distribution of monthly PET in mm", show.names = FALSE, pars=list(ylim = ylim, cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
+    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), main = "Box plot of the monthly estimations of ET", boxwex = 0.5, range = 0, xlab = "", ylab = "Distribution of monthly PET in mm", show.names = FALSE, pars=list(ylim = ylim, cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
     legend("topright", inset = .01, c(paste(legtext[1:Ncomp])), cex = (1), fill = c(seq(from=2,to=Ncomp+1)), bty="o")
     
   }
@@ -370,7 +369,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     if (is.null(results1$ET.Annual) | is.null(results2$ET.Annual)) {
       stop("Unable to compare results because estimations of annual ET are not available in both results1 and results2")
     }
-    x.Date <- floor(as.numeric(as.yearmon(time(results1$ET.Annual[which(time(results$ET.Annual) == floor(as.numeric(as.yearmon(Sdate)))):which(time(results1$ET.Annual) == floor(as.numeric(as.yearmon(Edate))))]))))
+    x.Date <- floor(as.numeric(as.yearmon(time(results1$ET.Annual[which(time(results1$ET.Annual) == floor(as.numeric(as.yearmon(Sdate)))):which(time(results1$ET.Annual) == floor(as.numeric(as.yearmon(Edate))))]))))
     
     comp <- matrix(nrow=length(x.Date),ncol=Ncomp+1)
     comp[,1] <- x.Date
@@ -435,7 +434,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
       ylim[2] <- max(results1$ET.Annual)*1.5
     }
     
-    plot(comp[,2]~floor(as.numeric(as.yearmon(comp[,1]))), type = "l", main = "Annual estimations of ET",  ylim = ylim, col = 2, xlab = "Year", ylab = "Annual aggregations of estimated ET mm/year", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(comp[,2]~floor(as.numeric(as.yearmon(comp[,1]))), type = "l", main = "Annual estimations of ET",  ylim = ylim, col = 2, xlab = "Year", ylab = "Annual aggregations of estimated ET mm/year", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (i in 1:(Ncomp-1)) {
       lines(comp[,i+2]~floor(as.numeric(as.yearmon(comp[,1]))), type = "l", col = i+2)
     }
@@ -452,7 +451,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     }
     sortcomp[,Ncomp+2] <- seq(from = 1/nrow(sortcomp), to = 1, by = 1/nrow(sortcomp))
     
-    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the annual ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Annual aggregations of estimated ET mm/year", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the annual ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Annual aggregations of estimated ET mm/year", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (k in 1:(Ncomp-1)) {
       lines(sortcomp[,k+2]~sortcomp[,Ncomp+2], type = "o", pch = ".", col = k+2)
     }
@@ -462,11 +461,17 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     # Box plot
     par(ask=TRUE)
     colnames(comp)[2:(Ncomp+1)] <- legtext
-    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the annual estimations of ET", xlab = "", ylab = "Distribution of annual PET in mm", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
+    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the annual estimations of ET", xlab = "", ylab = "Distribution of annual PET in mm", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
     legend("topright", inset = .01, c(paste(legtext[1:Ncomp])), cex = (1), fill = c(seq(from=2,to=Ncomp+1)), bty="o")
   }
   
   if (type == "MonthlyAve") {
+    if (is.null(Sdate)) {
+      Sdate = time(results1$ET.MonthlyAve)[1]
+    }
+    if (is.null(Edate)) {
+      Edate = time(results1$ET.MonthlyAve)[length(results1$ET.MonthlyAve)]
+    }
     
     # Monthly average
     par(ask=FALSE)
@@ -474,6 +479,8 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
       stop("Unable to compare results because estimations of monthly averaged ET are not available in both results1 and results2")
     }
     
+    x.Date <- floor(as.numeric(as.yearmon(time(results1$ET.MonthlyAve[which(time(results1$ET.MonthlyAve) == floor(as.numeric(as.yearmon(Sdate)))):which(time(results1$ET.MonthlyAve) == floor(as.numeric(as.yearmon(Edate))))]))))
+    
     comp <- matrix(nrow=length(results1$ET.MonthlyAve),ncol=Ncomp+1)
     comp[,1] <- x.Date
     comp[,2] <- results1$ET.MonthlyAve
@@ -536,7 +543,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
       ylim[2] <- max(results1$ET.MonthlyAve)*1.5
     }
     
-    plot(comp[,2]~unique(1:12), type = "l", main = "Monthly average ET",  ylim = ylim, col = 2, xlab = "Month", ylab = "Monthly averages of estimated daily ET mm/day", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(comp[,2]~unique(1:12), type = "l", main = "Monthly average ET",  ylim = ylim, col = 2, xlab = "Month", ylab = "Monthly averages of estimated daily ET mm/day", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (i in 1:(Ncomp-1)) {
       lines(comp[,i+2]~unique(1:12), type = "o", pch = ".", col = i+2)
     }
@@ -553,7 +560,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     }
     sortcomp[,Ncomp+2] <- seq(from = 1/nrow(sortcomp), to = 1, by = 1/nrow(sortcomp))
     
-    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the monthly average ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Monthly averages of estimated daily ET mm/day", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the monthly average ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Monthly averages of estimated daily ET mm/day", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (k in 1:(Ncomp-1)) {
       lines(sortcomp[,k+2]~sortcomp[,Ncomp+2], type = "o", pch = ".", col = k+2)
     }
@@ -563,7 +570,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     # Box plot
     par(ask=TRUE)
     colnames(comp)[2:(Ncomp+1)] <- legtext
-    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the monthly average ET", xlab = "", ylab = "Distribution of monthly averaged PET in mm/day", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
+    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the monthly average ET", xlab = "", ylab = "Distribution of monthly averaged PET in mm/day", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
     legend("topright", inset = .01, c(paste(legtext[1:Ncomp])), cex = (1), fill = c(seq(from=2,to=Ncomp+1)), bty="o")
   }
   
@@ -574,6 +581,9 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     if (is.null(results1$ET.AnnualAve) | is.null(results2$ET.AnnualAve)) {
       stop("Unable to compare results because estimations of annually averaged ET are not available in both results1 and results2")
     }
+    
+    x.Date <- floor(as.numeric(as.yearmon(time(results1$ET.AnnualAve[which(time(results1$ET.AnnualAve) == floor(as.numeric(as.yearmon(Sdate)))):which(time(results1$ET.AnnualAve) == floor(as.numeric(as.yearmon(Edate))))]))))
+    
     comp <- matrix(nrow=length(results1$ET.AnnualAve),ncol=Ncomp+1)
     comp[,1] <- x.Date
     comp[,2] <- results1$ET.AnnualAve
@@ -634,7 +644,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
       ylim[2] <- max(results1$ET.AnnualAve)*1.5
     }
     
-    plot(comp[,2]~floor(as.numeric(as.yearmon(time(results1$ET.Annual)))), type = "l", main = "Annually average ET",  ylim = ylim, col = 2, xlab = "Month", ylab = "Annual averages of estimated daily ET mm/day", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(comp[,2]~floor(as.numeric(as.yearmon(time(results1$ET.Annual)))), type = "l", main = "Annually average ET",  ylim = ylim, col = 2, xlab = "Month", ylab = "Annual averages of estimated daily ET mm/day", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (i in 1:(Ncomp-1)) {
       lines(comp[,i+2]~floor(as.numeric(as.yearmon(time(results1$ET.Annual)))), type = "l", col = i+2)
     }
@@ -651,7 +661,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     }
     sortcomp[,Ncomp+2] <- seq(from = 1/nrow(sortcomp), to = 1, by = 1/nrow(sortcomp))
     
-    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the annual average ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Annual averages of estimated daily ET mm/day", cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
+    plot(sortcomp[,2]~sortcomp[,Ncomp+2], type = "l", main = "Non-exceedance probability of the annual average ET", xlim = c(0,1), ylim = ylim, col = 2, xlab = "Non-exceedance probability", ylab = "Annual averages of estimated daily ET mm/day", cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1)))
     for (k in 1:(Ncomp-1)) {
       lines(sortcomp[,k+2]~sortcomp[,Ncomp+2], type = "o", pch = ".", col = k+2)
     }
@@ -661,7 +671,7 @@ ETComparison <- function(results1, results2, results3 = NULL, results4 = NULL, r
     # Box plot
     par(ask=TRUE)
     colnames(comp)[2:(Ncomp+1)] <- legtext
-    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the annual average ET", xlab = "", ylab = "Distribution ofannually averaged PET in mm/day", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.9, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
+    boxplot(comp[,2:(Ncomp+1)], col = c(seq(from=2,to=Ncomp+1)), boxwex = 0.5, range = 0, main = "Box plot of the annual average ET", xlab = "", ylab = "Distribution ofannually averaged PET in mm/day", show.names = FALSE, pars = list(ylim = ylim, cex.lab = 1.3, cex.main = 2.1, par(mar = c(5.1,4.7,4.7,2.1))))
     legend("topright", inset = .01, c(paste(legtext[1:Ncomp])), cex = (1), fill = c(seq(from=2,to=Ncomp+1)), bty="o")
   }
   par(ask=FALSE)
